**Devlog guidelines:**
- All new code needs to be tested and documented. Add daily tasks accordingly.
- The written dissertation (or at least the notes to write it) needs to move along with all the other goals.

# Daily sprint goals

- set up pylint **FAILED**

# Tasks for the day

- [ ] write github action workflow **FAILED**

# Notes

- future tasks:
	- set up pandoc on server to compile docs? (remove from model otherwise)
	- correct upload *pretrained* model in sequence diagram

# Shutdown and Retrospective

- [ ] test and validate all new code **FAILED**
- [ ] commit to the remote repo **FAILED**
- [x] make a schedule for tomorrow

**Did anything go wrong? What could have been done better, and how?**
-  I still have no code ready. I'm behind on UML diagrams. Today was terrible on all aspects.
- I missed all the tasks and failed all the goals for the day. The day was completely lost on subtasks that seem necessary yet completely ineffective in progressing the main goal. Progress is terribly non-linear and I cannot make a decent estimate on how much time this project will take. I hope in a major breakthrough soon but I can't really tell.